use_close_menu_context

Function use_close_menu_context 

pub fn use_close_menu_context<'hook>() -> impl 'hook + Hook<Output = Option<CloseMenuContext>>
Access the menu context.

This will only return a non-none value when called from a component nested in a component supporting this context.

Note

When used in function components and hooks, this hook is equivalent to:

/// Access the menu context.
///
/// This will only return a non-none value when called from a component nested in a component
/// supporting this context.
pub fn use_close_menu_context() -> Option<CloseMenuContext> {
    /* implementation omitted */
}