pub enum ResultsCount {
Absolute(usize),
Fraction(usize, usize),
}Expand description
The number of search results returned. Either a total number of results, or an index of the current result in relation to total results.
Variants