pub struct SearchInputExpandableProperties {
pub expanded: bool,
pub ontoggleexpand: Callback<(MouseEvent, bool)>,
pub toggle_aria_label: AttrValue,
}Expand description
Properties for creating an expandable search input. These properties should be passed into the search input component’s expandableInput property.
Fields
expanded: boolFlag to indicate if the search input is expanded.
ontoggleexpand: Callback<(MouseEvent, bool)>Callback function to toggle the expandable search input.
toggle_aria_label: AttrValueAn accessible label for the expandable search input toggle.