pub struct ToggleGroupItemProperties {
pub text: OptionalHtml,
pub icon: OptionalHtml,
pub class: Classes,
pub disabled: bool,
pub selected: bool,
pub onchange: Callback<()>,
pub button_ref: NodeRef,
}Fields
text: OptionalHtmlText rendered inside the toggle group item
icon: OptionalHtmlIcon rendered inside the toggle group item
class: ClassesAdditional classes added to the toggle group item
disabled: boolFlag indicating if the toggle group item is disabled
selected: boolFlag indicating if the toggle group item is selected
onchange: Callback<()>A callback for when the toggle group item selection changes
A reference to the button which emits the event for onchange.