pub struct ExpandableSectionToggleProperties {
pub children: Children,
pub toggle_text_hidden: AttrValue,
pub toggle_text_expanded: AttrValue,
pub expanded: bool,
pub direction: ExpandableSectionToggleDirection,
pub ontoggle: Callback<()>,
pub no_icon: bool,
/* private fields */
}Expand description
Properties for ExpandableSectionToggle
Fields
children: ChildrenAlternate children
Setting any children will disable the automatic toggle text from the properties
toggle_text_hidden and toggle_text_expanded.
toggle_text_expanded: AttrValueexpanded: booldirection: ExpandableSectionToggleDirectionontoggle: Callback<()>no_icon: boolTrait Implementations
Sourceimpl Clone for ExpandableSectionToggleProperties
impl Clone for ExpandableSectionToggleProperties
Sourcefn clone(&self) -> ExpandableSectionToggleProperties
fn clone(&self) -> ExpandableSectionToggleProperties
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for ExpandableSectionToggleProperties
impl PartialEq for ExpandableSectionToggleProperties
Sourcefn eq(&self, other: &ExpandableSectionToggleProperties) -> bool
fn eq(&self, other: &ExpandableSectionToggleProperties) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExpandableSectionToggleProperties