pub struct FileUploadDetailsProperties {
pub children: Html,
pub processing: bool,
pub invalid: bool,
}Fields
children: HtmlThe details section, supposed to be a single [crate::components::TextArea].
processing: boolSet flag if upload is processing.
This will render a spinner on the detail component section.
invalid: boolIf the validation state is invalid